@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2009 IBM Corporation and others.
+ * Copyright (c) 2000, 2013 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -478,8 +478,8 @@ public class DelegateASTVisitor extends ASTVisitor {
 	public void endVisit(WhileStatement whileStatement, BlockScope scope) {
 		visitor.endVisit(whileStatement);
 	}
-	public void endVisit(WithStatement whileStatement, BlockScope scope) {
-		visitor.endVisit(whileStatement);
+	public void endVisit(WithStatement withStatement, BlockScope scope) {
+		visitor.endVisit(withStatement);
 	}
 	public boolean visit(
     		AllocationExpression allocationExpression,
